pub struct Transactions { /* private fields */ }Expand description
Request descriptor for Gingr transaction lists over a validated provider date window.
Implementations
Sourceimpl Transactions
impl Transactions
Sourcepub fn builder() -> TransactionsBuilder
pub fn builder() -> TransactionsBuilder
Starts a builder that makes each provider parameter explicit before request capture.